"use strict";

require('dotenv').config();

let Config = require('config');
let Mojo = require('mojo-node-helper');

let fs = require('fs');
let optimist = require('optimist');
let argv = optimist
    .usage(`Usage: npm run test -- [script]`)
    .options('h', {
        alias: 'help',
        describe: 'show help'
    })
    .options('p', {
        alias: 'payload',
        describe: 'specify payload to test with'
    }).argv;

if (argv.help) {
    console.log();
    console.log(optimist.help());
    process.exit(0);
}

for (let i = 0; i < argv._.length; i++) {
    let testfile = argv._[i];
    if (testfile.length <= 3 || testfile.substr(-3) != '.js') {
        testfile = testfile + '.js';
    }
    Mojo.UtilHelper.inspect(testfile, 'Script');

    if (fs.existsSync(testfile)) {
        let lambda = require('./' + testfile);
        lambda.test(lambda.handler, argv, function (error, response) {
            if (error) {
                Mojo.UtilHelper.inspect(error, 'Error Response');
            } else {
                Mojo.UtilHelper.inspect(response, 'Success Response');
            }
        });
    } else {
        console.log('Error: ' + testfile + ' doesn\'t exist.');
    }
}